@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::IRC::Common::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Common::VERSION = '6.34';
+  $POE::Component::IRC::Common::VERSION = '6.36';
 }
 
 use strict;
@@ -532,7 +532,7 @@ Takes two parameters, a string representing an IRC mask ( it'll be processed
 with parse_ban_mask() to ensure that it is normalised ) and something to match
 against the IRC mask, such as a nick!user@hostname string. Returns a true
 value if they match, a false value otherwise. Optionally, one may pass the
-casemapping (see L<C<u_irc>|/"u_irc">), as this function uses C<u_irc>
+casemapping (see L<C<u_irc>|/u_irc>), as this function uses C<u_irc>
 internally.
 
 =head2 C<matches_mask_array>
@@ -541,7 +541,7 @@ Takes two array references, the first being a list of strings representing
 IRC masks, the second a list of somethings to test against the masks. Returns
 an empty hashref if there are no matches. Otherwise, the keys will be the
 masks matched, each value being an arrayref of the strings that matched it.
-Optionally, one may pass the casemapping (see L<C<u_irc>|/"u_irc">), as
+Optionally, one may pass the casemapping (see L<C<u_irc>|/u_irc>), as
 this function uses C<u_irc> internally.
 
 =head2 C<parse_user>
@@ -581,7 +581,7 @@ always do what you expect it to.
 =head2 C<irc_to_utf8>
 
 This function takes a byte string (e.g. a message from an
-L<C<irc_public>|POE::Component::IRC/"irc_public"> handler) in "IRC encoding"
+L<C<irc_public>|POE::Component::IRC/irc_public> handler) in "IRC encoding"
 and returns a text string. Since the source encoding might have been UTF-8,
 you should encode/store it in UTF-8 or some other Unicode encoding in your
 file/database/whatever.
